@@ -26,7 +26,7 @@ class Middleware:
         # app = setup_monitor_memory_middleware(app)
 
         # 设置cors
-        # app = setup_cors_handler(app)
+        app = setup_cors_handler(app)
 
         # 健康检查
         app = setup_health_handler(app)
